@@ -139,7 +139,7 @@ module Complex =
 struct
   type workspace
   type wavetable
-  type direction = | Backward | Forward
+  type direction = Forward | Backward
 
   external alloc_workspace : int -> workspace
       = "ml_gsl_fft_complex_workspace_alloc"
@@ -163,6 +163,14 @@ struct
     Gc.finalise free_wavetable wt ;
     wt
 
+  external forward :
+      ?stride:int -> complex_array -> wavetable -> workspace -> unit
+      = "ml_gsl_fft_complex_forward"
+
+  external forward_rad2 : 
+      ?dif:bool -> ?stride:int -> complex_array -> unit
+      = "ml_gsl_fft_complex_rad2_forward"
+
   external transform : 
       ?stride:int -> complex_array -> wavetable -> workspace -> direction -> unit
       = "ml_gsl_fft_complex_transform"
