@@ -10,6 +10,9 @@ external gaussian : Gsl_rng.t -> sigma:float -> float
 external gaussian_ratio_method : Gsl_rng.t -> sigma:float -> float
     = "ml_gsl_ran_gaussian_ratio_method"
 
+external gaussian_ziggurat : Gsl_rng.t -> sigma:float -> float 
+    = "ml_gsl_ran_gaussian_ziggurat"
+
 external gaussian_pdf : float -> sigma:float -> float
     = "ml_gsl_ran_gaussian_pdf" "gsl_ran_gaussian_pdf" "float"
 
@@ -109,9 +112,15 @@ external levy_skew : Gsl_rng.t -> c:float -> alpha:float -> beta:float -> float
 external gamma : Gsl_rng.t -> a:float -> b:float -> float 
     = "ml_gsl_ran_gamma"
 
+external gamma_int : Gsl_rng.t -> a:int -> float 
+    = "ml_gsl_ran_gamma_int"
+
 external gamma_pdf : float -> a:float -> b:float -> float
     = "ml_gsl_ran_gamma_pdf" "gsl_ran_gamma_pdf" "float"
 
+external gamma_mt : Gsl_rng.t -> a:int ->  b:float -> float
+    = "ml_gsl_ran_gamma_mt"
+
 (* FLAT *)
 external flat : Gsl_rng.t -> a:float -> b:float -> float 
     = "ml_gsl_ran_flat"
@@ -252,8 +261,11 @@ external bernoulli_pdf : int -> p:float -> float
 external binomial : Gsl_rng.t -> p:float -> n:int -> int
     = "ml_gsl_ran_binomial"
 
-external binomial_tpe : Gsl_rng.t -> pp:float -> n:int -> int
-    = "ml_gsl_ran_binomial"
+external binomial_knuth : Gsl_rng.t -> p:float -> n:int -> int
+    = "ml_gsl_ran_binomial_knuth"
+
+external binomial_tpe : Gsl_rng.t -> p:float -> n:int -> int
+    = "ml_gsl_ran_binomial_tpe"
 
 external binomial_pdf : int -> p:float -> n:int -> float
     = "ml_gsl_ran_binomial_pdf"
@@ -270,10 +282,10 @@ external multinomial_lnpdf : p:float array -> n:int array -> float
 
 
 (* NEGATIVE BINOMIAL *)
-external negative_binomial : Gsl_rng.t -> p:float -> n:float -> int
+external negative_binomial : Gsl_rng.t -> p:float -> n:int -> int
     = "ml_gsl_ran_negative_binomial"
 
-external negative_binomial_pdf : int -> p:float -> n:float -> float
+external negative_binomial_pdf : int -> p:float -> n:int -> float
     = "ml_gsl_ran_negative_binomial_pdf"
 
 (* PASCAL *)
