@@ -1,5 +1,5 @@
 /* ocamlgsl - OCaml interface to GSL                        */
-/* Copyright () 2002 - Olivier Andrieu                     */
+/* Copyright (©) 2002-2005 - Olivier Andrieu                */
 /* distributed under the terms of the GPL version 2         */
 
 #ifndef _MLGSL_WRAPPERS_
@@ -52,22 +52,22 @@ static inline value copy_two_double_arr(double a, double b)
   ( v=alloc_small(1, Abstract_tag), Field(v, 0)=Val_bp(p) )
 
 #define ML1(name, conv1, convr) \
-  value ml_##name(value arg1) \
+  CAMLprim value ml_##name(value arg1) \
   { return convr(name(conv1(arg1))) ; }
 #define ML1_alloc(name, conv1, convr) \
-  value ml_##name(value arg1) \
+  CAMLprim value ml_##name(value arg1) \
   { value res; convr(res, name(conv1(arg1))); return res; }
 #define ML2(name, conv1, conv2, convr) \
-  value ml_##name(value arg1, value arg2) \
+  CAMLprim value ml_##name(value arg1, value arg2) \
   { return convr(name(conv1(arg1), conv2(arg2))) ; }
 #define ML3(name, conv1, conv2, conv3, convr) \
-  value ml_##name(value arg1, value arg2, value arg3) \
+  CAMLprim value ml_##name(value arg1, value arg2, value arg3) \
   { return convr(name(conv1(arg1), conv2(arg2), conv3(arg3))) ; }
 #define ML4(name, conv1, conv2, conv3, conv4, convr) \
-  value ml_##name(value arg1, value arg2, value arg3, value arg4) \
+  CAMLprim value ml_##name(value arg1, value arg2, value arg3, value arg4) \
   { return convr(name(conv1(arg1), conv2(arg2), conv3(arg3), conv4(arg4))) ; }
 #define ML5(name, conv1, conv2, conv3, conv4, conv5, convr) \
-  value ml_##name(value arg1, value arg2, value arg3, value arg4, value arg5) \
+  CAMLprim value ml_##name(value arg1, value arg2, value arg3, value arg4, value arg5) \
   { return convr(name(conv1(arg1), conv2(arg2), conv3(arg3), conv4(arg4), conv5(arg5))) ; }
 
 #define CONCAT2x(a,b) a ## _ ## b
